@@ -1,18 +1,16 @@
+use super::send_api_request;
 use crate::api::{
     configuration::{api_url, ImgurClient},
     ImageInfo,
 };
 
-use super::send_api_request;
-
-use anyhow::Error as anyhow_err;
 use reqwest::Method;
 use std::{
     collections::HashMap,
     io::{Error, ErrorKind},
 };
 
-pub async fn upload_image(c: ImgurClient, image: &str) -> Result<ImageInfo, anyhow_err> {
+pub async fn upload_image(c: ImgurClient, image: &str) -> Result<ImageInfo, anyhow::Error> {
     let mut form = HashMap::new();
 
     form.insert("image", image.to_string());
@@ -23,15 +21,20 @@ pub async fn upload_image(c: ImgurClient, image: &str) -> Result<ImageInfo, anyh
     let status = res.status();
 
     if status.is_client_error() || status.is_server_error() {
-        let body = res.text().await.map_err(anyhow_err::new)?;
+        let mut body = res.text().await.map_err(anyhow::Error::new)?;
+
+        if body.chars().count() > 30 {
+            body = "body is too length".to_string()
+        }
+
         let err = Error::new(
             ErrorKind::Other,
             format!("server returned non-successful status code = {status}, body = {body}"),
         );
 
-        Err(anyhow_err::from(err))
+        Err(anyhow::Error::from(err))
     } else {
-        let content: ImageInfo = res.json().await.map_err(anyhow_err::new)?;
+        let content: ImageInfo = res.json().await.map_err(anyhow::Error::new)?;
         Ok(content)
     }
 }
